@@ -1,20 +1,22 @@
-"""Python Luxafor BLE module"""
+"""Python Luxafor BLE module.
 
-__all__ = ('LuxaforDot','discover',)
+Contains methods for discovering devices.
+"""
 
-__author__ = """Matt Lizzie"""
-__email__ = 'matt@lizzie.pro'
-__version__ = '0.0.1'
+__all__ = ("LuxaforDot", "discover")
+
+__version__ = "0.0.2"
 
 from luxafor_base import LuxaforDevice
-from .scanner import discover_dots
+
 from .dot import LuxaforDot
+from .scanner import discover_dots
+
 
 async def discover() -> list[LuxaforDevice]:
-    """Discover all available devices
+    """Discover all available devices.
 
     Returns:
         list[LuxaforDevice]: List of discovered devices
     """
     return await discover_dots()
-
